Struct rustsec_admin::prelude::span::Attributes [−][src]
pub struct Attributes<'a> { /* fields omitted */ }Expand description
Attributes provided to a Subscriber describing a new span when it is
created.
Implementations
Returns Attributes describing a new child span of the current span,
with the provided metadata and values.
pub fn new_root(
metadata: &'static Metadata<'static>,
values: &'a ValueSet<'a>
) -> Attributes<'a>
pub fn new_root(
metadata: &'static Metadata<'static>,
values: &'a ValueSet<'a>
) -> Attributes<'a>
Returns Attributes describing a new span at the root of its own trace
tree, with the provided metadata and values.
Returns Attributes describing a new child span of the specified
parent span, with the provided metadata and values.
Returns a reference to the new span’s metadata.
Returns a reference to a ValueSet containing any values the new span
was created with.
Returns true if the new span’s parent should be determined based on the current context.
If this is true and the current thread is currently inside a span, then that span should be the new span’s parent. Otherwise, if the current thread is not inside a span, then the new span will be the root of its own trace tree.
Returns the new span’s explicitly-specified parent, if there is one.
Otherwise (if the new span is a root or is a child of the current span), returns false.
Records all the fields in this set of Attributes with the provided
Visitor.
Returns true if this set of Attributes contains a value for the
given Field.
Returns the set of all fields defined by this span’s Metadata.
Note that the FieldSet returned by this method includes all the
fields declared by this span, not just those with values that are recorded
as part of this set of Attributes. Other fields with values not present in
this Attributes’ value set may record values later.