[−][src]Trait rustsec_admin::prelude::Runnable
Runnable is a common trait for things which can be run without any
arguments.
Its primary intended purpose is for use in conjunction with Command.
Required methods
fn run(&self)
Run this Runnable
Implementations on Foreign Types
impl<Cmd> Runnable for EntryPoint<Cmd> where
Cmd: Command + Runnable, [src]
Cmd: Command + Runnable,
impl Runnable for Box<dyn Fn() + 'static>[src]
impl<C> Runnable for Help<C> where
C: Command, [src]
Loading content...C: Command,